==> huaweicloudsdkworkspaceapp-3.1.142-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/resend_authorization_mail_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResendAuthorizationMailReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'records': 'list[AuthorizationMail]'
    }

    attribute_map = {
        'records': 'records'
    }

    def __init__(self, records=None):
        """ResendAuthorizationMailReq

        The model defined in huaweicloud sdk

        :param records: 邮件记录。
        :type records: list[:class:`huaweicloudsdkworkspaceapp.v1.AuthorizationMail`]
        """
        
        

        self._records = None
        self.discriminator = None

        self.records = records

    @property
    def records(self):
        """Gets the records of this ResendAuthorizationMailReq.

        邮件记录。

        :return: The records of this ResendAuthorizationMailReq.
        :rtype: list[:class:`huaweicloudsdkworkspaceapp.v1.AuthorizationMail`]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this ResendAuthorizationMailReq.

        邮件记录。

        :param records: The records of this ResendAuthorizationMailReq.
        :type records: list[:class:`huaweicloudsdkworkspaceapp.v1.AuthorizationMail`]
        """
        self._records = records

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResendAuthorizationMailReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.154-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/resend_authorization_mail_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResendAuthorizationMailReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'records': 'list[AuthorizationMail]'
    }

    attribute_map = {
        'records': 'records'
    }

    def __init__(self, records=None):
        r"""ResendAuthorizationMailReq

        The model defined in huaweicloud sdk

        :param records: 邮件记录。
        :type records: list[:class:`huaweicloudsdkworkspaceapp.v1.AuthorizationMail`]
        """
        
        

        self._records = None
        self.discriminator = None

        self.records = records

    @property
    def records(self):
        r"""Gets the records of this ResendAuthorizationMailReq.

        邮件记录。

        :return: The records of this ResendAuthorizationMailReq.
        :rtype: list[:class:`huaweicloudsdkworkspaceapp.v1.AuthorizationMail`]
        """
        return self._records

    @records.setter
    def records(self, records):
        r"""Sets the records of this ResendAuthorizationMailReq.

        邮件记录。

        :param records: The records of this ResendAuthorizationMailReq.
        :type records: list[:class:`huaweicloudsdkworkspaceapp.v1.AuthorizationMail`]
        """
        self._records = records

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResendAuthorizationMailReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
